Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2009-06-05 20:11:18 +0400
committerTon Roosendaal <ton@blender.org>2009-06-05 20:11:18 +0400
commit45ed196344a7534c9965015ca653c90f5f00d97f (patch)
treeb6401a2ea9ef1d0c4addfa9ef3dc52cf26bd27a1 /source/blender/windowmanager/intern
parentf7e5fd94386cada0e800e9dcd66492cc77e1c201 (diff)
2.5
Search menu: - Made nicer drawing for popup version of search. It now uses entire backdrop like pulldowns. Search boxes for text buttons will use different style still; if we use this option all over it shouldn't look too intrusive. - Search menu allows scroll, to view all items. It doesn't cycle anymore. - Click outside search menu now cancels - If a match is in search button, it highlights it. This also allows ALT+CTRL+F - Enter to redo last op. - Search popup draws higher when no no space below. No order flipping!
Diffstat (limited to 'source/blender/windowmanager/intern')
-rw-r--r--source/blender/windowmanager/intern/wm_operators.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/source/blender/windowmanager/intern/wm_operators.c b/source/blender/windowmanager/intern/wm_operators.c
index 418a231a7e9..3b6d605df61 100644
--- a/source/blender/windowmanager/intern/wm_operators.c
+++ b/source/blender/windowmanager/intern/wm_operators.c
@@ -423,7 +423,10 @@ static uiBlock *wm_block_search_menu(bContext *C, ARegion *ar, void *arg_op)
but= uiDefSearchBut(block, search, 0, ICON_VIEWZOOM, 256, 10, 10, 180, 19, "");
uiButSetSearchFunc(but, operator_search_cb, NULL, operator_call_cb);
- uiPopupBoundsBlock(block, 0.0f, 0, -20); /* move it downwards, mouse over button */
+ /* fake button, it holds space for search items */
+ uiDefBut(block, LABEL, 0, "", 10, 10 - uiSearchBoxhHeight(), 180, uiSearchBoxhHeight(), NULL, 0, 0, 0, 0, NULL);
+
+ uiPopupBoundsBlock(block, 6.0f, 0, -20); /* move it downwards, mouse over button */
uiEndBlock(C, block);
event= *(win->eventstate); /* XXX huh huh? make api call */